# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class IngestMappingSchema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'i_agent': 'IngestmappingSchemaIAgent',
        'name': 'str',
        'native_gpb': 'IngestmappingSchemaNativegpb',
        'netflow': 'IngestmappingSchemaNetflow',
        'open_config': 'IngestmappingSchemaOpenconfig',
        'server_monitoring': 'IngestmappingSchemaOpenconfig',
        'snmp': 'IngestmappingSchemaSnmp',
        'syslog': 'IngestmappingSchemaSyslog'
    }

    attribute_map = {
        'i_agent': 'iAgent',
        'name': 'name',
        'native_gpb': 'native-gpb',
        'netflow': 'netflow',
        'open_config': 'open-config',
        'server_monitoring': 'server-monitoring',
        'snmp': 'snmp',
        'syslog': 'syslog'
    }

    def __init__(self, i_agent=None, name=None, native_gpb=None, netflow=None, open_config=None, server_monitoring=None, snmp=None, syslog=None):  # noqa: E501
        """IngestMappingSchema - a model defined in Swagger"""  # noqa: E501

        self._i_agent = None
        self._name = None
        self._native_gpb = None
        self._netflow = None
        self._open_config = None
        self._server_monitoring = None
        self._snmp = None
        self._syslog = None
        self.discriminator = None

        if i_agent is not None:
            self.i_agent = i_agent
        self.name = name
        if native_gpb is not None:
            self.native_gpb = native_gpb
        if netflow is not None:
            self.netflow = netflow
        if open_config is not None:
            self.open_config = open_config
        if server_monitoring is not None:
            self.server_monitoring = server_monitoring
        if snmp is not None:
            self.snmp = snmp
        if syslog is not None:
            self.syslog = syslog

    @property
    def i_agent(self):
        """Gets the i_agent of this IngestMappingSchema.  # noqa: E501


        :return: The i_agent of this IngestMappingSchema.  # noqa: E501
        :rtype: IngestmappingSchemaIAgent
        """
        return self._i_agent

    @i_agent.setter
    def i_agent(self, i_agent):
        """Sets the i_agent of this IngestMappingSchema.


        :param i_agent: The i_agent of this IngestMappingSchema.  # noqa: E501
        :type: IngestmappingSchemaIAgent
        """

        self._i_agent = i_agent

    @property
    def name(self):
        """Gets the name of this IngestMappingSchema.  # noqa: E501

        Name of the mapping  # noqa: E501

        :return: The name of this IngestMappingSchema.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IngestMappingSchema.

        Name of the mapping  # noqa: E501

        :param name: The name of this IngestMappingSchema.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if name is not None and len(name) > 64:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `64`")  # noqa: E501
        if name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', name):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._name = name

    @property
    def native_gpb(self):
        """Gets the native_gpb of this IngestMappingSchema.  # noqa: E501


        :return: The native_gpb of this IngestMappingSchema.  # noqa: E501
        :rtype: IngestmappingSchemaNativegpb
        """
        return self._native_gpb

    @native_gpb.setter
    def native_gpb(self, native_gpb):
        """Sets the native_gpb of this IngestMappingSchema.


        :param native_gpb: The native_gpb of this IngestMappingSchema.  # noqa: E501
        :type: IngestmappingSchemaNativegpb
        """

        self._native_gpb = native_gpb

    @property
    def netflow(self):
        """Gets the netflow of this IngestMappingSchema.  # noqa: E501


        :return: The netflow of this IngestMappingSchema.  # noqa: E501
        :rtype: IngestmappingSchemaNetflow
        """
        return self._netflow

    @netflow.setter
    def netflow(self, netflow):
        """Sets the netflow of this IngestMappingSchema.


        :param netflow: The netflow of this IngestMappingSchema.  # noqa: E501
        :type: IngestmappingSchemaNetflow
        """

        self._netflow = netflow

    @property
    def open_config(self):
        """Gets the open_config of this IngestMappingSchema.  # noqa: E501


        :return: The open_config of this IngestMappingSchema.  # noqa: E501
        :rtype: IngestmappingSchemaOpenconfig
        """
        return self._open_config

    @open_config.setter
    def open_config(self, open_config):
        """Sets the open_config of this IngestMappingSchema.


        :param open_config: The open_config of this IngestMappingSchema.  # noqa: E501
        :type: IngestmappingSchemaOpenconfig
        """

        self._open_config = open_config

    @property
    def server_monitoring(self):
        """Gets the server_monitoring of this IngestMappingSchema.  # noqa: E501


        :return: The server_monitoring of this IngestMappingSchema.  # noqa: E501
        :rtype: IngestmappingSchemaOpenconfig
        """
        return self._server_monitoring

    @server_monitoring.setter
    def server_monitoring(self, server_monitoring):
        """Sets the server_monitoring of this IngestMappingSchema.


        :param server_monitoring: The server_monitoring of this IngestMappingSchema.  # noqa: E501
        :type: IngestmappingSchemaOpenconfig
        """

        self._server_monitoring = server_monitoring

    @property
    def snmp(self):
        """Gets the snmp of this IngestMappingSchema.  # noqa: E501


        :return: The snmp of this IngestMappingSchema.  # noqa: E501
        :rtype: IngestmappingSchemaSnmp
        """
        return self._snmp

    @snmp.setter
    def snmp(self, snmp):
        """Sets the snmp of this IngestMappingSchema.


        :param snmp: The snmp of this IngestMappingSchema.  # noqa: E501
        :type: IngestmappingSchemaSnmp
        """

        self._snmp = snmp

    @property
    def syslog(self):
        """Gets the syslog of this IngestMappingSchema.  # noqa: E501


        :return: The syslog of this IngestMappingSchema.  # noqa: E501
        :rtype: IngestmappingSchemaSyslog
        """
        return self._syslog

    @syslog.setter
    def syslog(self, syslog):
        """Sets the syslog of this IngestMappingSchema.


        :param syslog: The syslog of this IngestMappingSchema.  # noqa: E501
        :type: IngestmappingSchemaSyslog
        """

        self._syslog = syslog

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IngestMappingSchema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IngestMappingSchema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TsdbSchema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dedicate': 'bool',
        'nodes': 'list[str]',
        'replication_factor': 'int'
    }

    attribute_map = {
        'dedicate': 'dedicate',
        'nodes': 'nodes',
        'replication_factor': 'replication-factor'
    }

    def __init__(self, dedicate=None, nodes=None, replication_factor=None):  # noqa: E501
        """TsdbSchema - a model defined in Swagger"""  # noqa: E501

        self._dedicate = None
        self._nodes = None
        self._replication_factor = None
        self.discriminator = None

        if dedicate is not None:
            self.dedicate = dedicate
        if nodes is not None:
            self.nodes = nodes
        if replication_factor is not None:
            self.replication_factor = replication_factor

    @property
    def dedicate(self):
        """Gets the dedicate of this TsdbSchema.  # noqa: E501

        Dedicate given nodes only for tsdb instances. No other services will be spawned on tsdb nodes when set to true  # noqa: E501

        :return: The dedicate of this TsdbSchema.  # noqa: E501
        :rtype: bool
        """
        return self._dedicate

    @dedicate.setter
    def dedicate(self, dedicate):
        """Sets the dedicate of this TsdbSchema.

        Dedicate given nodes only for tsdb instances. No other services will be spawned on tsdb nodes when set to true  # noqa: E501

        :param dedicate: The dedicate of this TsdbSchema.  # noqa: E501
        :type: bool
        """

        self._dedicate = dedicate

    @property
    def nodes(self):
        """Gets the nodes of this TsdbSchema.  # noqa: E501


        :return: The nodes of this TsdbSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._nodes

    @nodes.setter
    def nodes(self, nodes):
        """Sets the nodes of this TsdbSchema.


        :param nodes: The nodes of this TsdbSchema.  # noqa: E501
        :type: list[str]
        """

        self._nodes = nodes

    @property
    def replication_factor(self):
        """Gets the replication_factor of this TsdbSchema.  # noqa: E501

        High availability. Number of copies of data to be stored  # noqa: E501

        :return: The replication_factor of this TsdbSchema.  # noqa: E501
        :rtype: int
        """
        return self._replication_factor

    @replication_factor.setter
    def replication_factor(self, replication_factor):
        """Sets the replication_factor of this TsdbSchema.

        High availability. Number of copies of data to be stored  # noqa: E501

        :param replication_factor: The replication_factor of this TsdbSchema.  # noqa: E501
        :type: int
        """

        self._replication_factor = replication_factor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TsdbSchema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsdbSchema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ResourceSchema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'depends_on': 'list[TopicSchemaDependson]',
        'description': 'str',
        'field': 'list[TopicSchemaField]',
        'function': 'list[TopicSchemaFunction]',
        'keys': 'list[str]',
        'resource_name': 'str'
    }

    attribute_map = {
        'depends_on': 'depends-on',
        'description': 'description',
        'field': 'field',
        'function': 'function',
        'keys': 'keys',
        'resource_name': 'resource-name'
    }

    def __init__(self, depends_on=None, description=None, field=None, function=None, keys=None, resource_name=None):  # noqa: E501
        """ResourceSchema - a model defined in Swagger"""  # noqa: E501

        self._depends_on = None
        self._description = None
        self._field = None
        self._function = None
        self._keys = None
        self._resource_name = None
        self.discriminator = None

        if depends_on is not None:
            self.depends_on = depends_on
        if description is not None:
            self.description = description
        if field is not None:
            self.field = field
        if function is not None:
            self.function = function
        if keys is not None:
            self.keys = keys
        self.resource_name = resource_name

    @property
    def depends_on(self):
        """Gets the depends_on of this ResourceSchema.  # noqa: E501


        :return: The depends_on of this ResourceSchema.  # noqa: E501
        :rtype: list[TopicSchemaDependson]
        """
        return self._depends_on

    @depends_on.setter
    def depends_on(self, depends_on):
        """Sets the depends_on of this ResourceSchema.


        :param depends_on: The depends_on of this ResourceSchema.  # noqa: E501
        :type: list[TopicSchemaDependson]
        """

        self._depends_on = depends_on

    @property
    def description(self):
        """Gets the description of this ResourceSchema.  # noqa: E501

        Description about the resource  # noqa: E501

        :return: The description of this ResourceSchema.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ResourceSchema.

        Description about the resource  # noqa: E501

        :param description: The description of this ResourceSchema.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def field(self):
        """Gets the field of this ResourceSchema.  # noqa: E501


        :return: The field of this ResourceSchema.  # noqa: E501
        :rtype: list[TopicSchemaField]
        """
        return self._field

    @field.setter
    def field(self, field):
        """Sets the field of this ResourceSchema.


        :param field: The field of this ResourceSchema.  # noqa: E501
        :type: list[TopicSchemaField]
        """

        self._field = field

    @property
    def function(self):
        """Gets the function of this ResourceSchema.  # noqa: E501


        :return: The function of this ResourceSchema.  # noqa: E501
        :rtype: list[TopicSchemaFunction]
        """
        return self._function

    @function.setter
    def function(self, function):
        """Sets the function of this ResourceSchema.


        :param function: The function of this ResourceSchema.  # noqa: E501
        :type: list[TopicSchemaFunction]
        """

        self._function = function

    @property
    def keys(self):
        """Gets the keys of this ResourceSchema.  # noqa: E501


        :return: The keys of this ResourceSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._keys

    @keys.setter
    def keys(self, keys):
        """Sets the keys of this ResourceSchema.


        :param keys: The keys of this ResourceSchema.  # noqa: E501
        :type: list[str]
        """

        self._keys = keys

    @property
    def resource_name(self):
        """Gets the resource_name of this ResourceSchema.  # noqa: E501

        Name of the resource. Should be of pattern [a-z][a-z0-9-]*  # noqa: E501

        :return: The resource_name of this ResourceSchema.  # noqa: E501
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """Sets the resource_name of this ResourceSchema.

        Name of the resource. Should be of pattern [a-z][a-z0-9-]*  # noqa: E501

        :param resource_name: The resource_name of this ResourceSchema.  # noqa: E501
        :type: str
        """
        if resource_name is None:
            raise ValueError("Invalid value for `resource_name`, must not be `None`")  # noqa: E501
        if resource_name is not None and len(resource_name) > 64:
            raise ValueError("Invalid value for `resource_name`, length must be less than or equal to `64`")  # noqa: E501
        if resource_name is not None and len(resource_name) < 1:
            raise ValueError("Invalid value for `resource_name`, length must be greater than or equal to `1`")  # noqa: E501
        if resource_name is not None and not re.search(r'^[a-z][a-z0-9-]*$', resource_name):  # noqa: E501
            raise ValueError(r"Invalid value for `resource_name`, must be a follow pattern or equal to `/^[a-z][a-z0-9-]*$/`")  # noqa: E501

        self._resource_name = resource_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResourceSchema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceSchema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class NotificationSchemaAmqppublish(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'exchange': 'str',
        'host': 'str',
        'port': 'int',
        'routing_key': 'str',
        'sasl': 'NotificationSchemaAmqppublishSasl',
        'vhost': 'str'
    }

    attribute_map = {
        'exchange': 'exchange',
        'host': 'host',
        'port': 'port',
        'routing_key': 'routing-key',
        'sasl': 'sasl',
        'vhost': 'vhost'
    }

    def __init__(self, exchange=None, host=None, port=None, routing_key=None, sasl=None, vhost=None):  # noqa: E501
        """NotificationSchemaAmqppublish - a model defined in Swagger"""  # noqa: E501

        self._exchange = None
        self._host = None
        self._port = None
        self._routing_key = None
        self._sasl = None
        self._vhost = None
        self.discriminator = None

        self.exchange = exchange
        self.host = host
        self.port = port
        if routing_key is not None:
            self.routing_key = routing_key
        if sasl is not None:
            self.sasl = sasl
        if vhost is not None:
            self.vhost = vhost

    @property
    def exchange(self):
        """Gets the exchange of this NotificationSchemaAmqppublish.  # noqa: E501

        Name of exchange/routing agent of amqp on which connection has to be instantiated  # noqa: E501

        :return: The exchange of this NotificationSchemaAmqppublish.  # noqa: E501
        :rtype: str
        """
        return self._exchange

    @exchange.setter
    def exchange(self, exchange):
        """Sets the exchange of this NotificationSchemaAmqppublish.

        Name of exchange/routing agent of amqp on which connection has to be instantiated  # noqa: E501

        :param exchange: The exchange of this NotificationSchemaAmqppublish.  # noqa: E501
        :type: str
        """
        if exchange is None:
            raise ValueError("Invalid value for `exchange`, must not be `None`")  # noqa: E501

        self._exchange = exchange

    @property
    def host(self):
        """Gets the host of this NotificationSchemaAmqppublish.  # noqa: E501

        Host is amqp server/broker valid hostname or IP address  # noqa: E501

        :return: The host of this NotificationSchemaAmqppublish.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this NotificationSchemaAmqppublish.

        Host is amqp server/broker valid hostname or IP address  # noqa: E501

        :param host: The host of this NotificationSchemaAmqppublish.  # noqa: E501
        :type: str
        """
        if host is None:
            raise ValueError("Invalid value for `host`, must not be `None`")  # noqa: E501

        self._host = host

    @property
    def port(self):
        """Gets the port of this NotificationSchemaAmqppublish.  # noqa: E501

        Port is amqp server/broker listner port  # noqa: E501

        :return: The port of this NotificationSchemaAmqppublish.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this NotificationSchemaAmqppublish.

        Port is amqp server/broker listner port  # noqa: E501

        :param port: The port of this NotificationSchemaAmqppublish.  # noqa: E501
        :type: int
        """
        if port is None:
            raise ValueError("Invalid value for `port`, must not be `None`")  # noqa: E501
        if port is not None and port > 65535:  # noqa: E501
            raise ValueError("Invalid value for `port`, must be a value less than or equal to `65535`")  # noqa: E501
        if port is not None and port < 1:  # noqa: E501
            raise ValueError("Invalid value for `port`, must be a value greater than or equal to `1`")  # noqa: E501

        self._port = port

    @property
    def routing_key(self):
        """Gets the routing_key of this NotificationSchemaAmqppublish.  # noqa: E501

        Routing key is a message attribute the exchange looks at when deciding how to route the message to queues. Should be of pattern \\.*[a-zA-Z0-9_-]+[a-zA-Z0-9\\._-]* , Default value is derived from <device/network-group>.<device-id>.<topic>.<rule>.<trigger>  # noqa: E501

        :return: The routing_key of this NotificationSchemaAmqppublish.  # noqa: E501
        :rtype: str
        """
        return self._routing_key

    @routing_key.setter
    def routing_key(self, routing_key):
        """Sets the routing_key of this NotificationSchemaAmqppublish.

        Routing key is a message attribute the exchange looks at when deciding how to route the message to queues. Should be of pattern \\.*[a-zA-Z0-9_-]+[a-zA-Z0-9\\._-]* , Default value is derived from <device/network-group>.<device-id>.<topic>.<rule>.<trigger>  # noqa: E501

        :param routing_key: The routing_key of this NotificationSchemaAmqppublish.  # noqa: E501
        :type: str
        """
        if routing_key is not None and len(routing_key) > 255:
            raise ValueError("Invalid value for `routing_key`, length must be less than or equal to `255`")  # noqa: E501
        if routing_key is not None and len(routing_key) < 1:
            raise ValueError("Invalid value for `routing_key`, length must be greater than or equal to `1`")  # noqa: E501
        if routing_key is not None and not re.search(r'^\\.*[a-zA-Z0-9_-]+[a-zA-Z0-9\\._-]*$', routing_key):  # noqa: E501
            raise ValueError(r"Invalid value for `routing_key`, must be a follow pattern or equal to `/^\\.*[a-zA-Z0-9_-]+[a-zA-Z0-9\\._-]*$/`")  # noqa: E501

        self._routing_key = routing_key

    @property
    def sasl(self):
        """Gets the sasl of this NotificationSchemaAmqppublish.  # noqa: E501


        :return: The sasl of this NotificationSchemaAmqppublish.  # noqa: E501
        :rtype: NotificationSchemaAmqppublishSasl
        """
        return self._sasl

    @sasl.setter
    def sasl(self, sasl):
        """Sets the sasl of this NotificationSchemaAmqppublish.


        :param sasl: The sasl of this NotificationSchemaAmqppublish.  # noqa: E501
        :type: NotificationSchemaAmqppublishSasl
        """

        self._sasl = sasl

    @property
    def vhost(self):
        """Gets the vhost of this NotificationSchemaAmqppublish.  # noqa: E501

        Virtual host of amqp on which connection has to be instantiated  # noqa: E501

        :return: The vhost of this NotificationSchemaAmqppublish.  # noqa: E501
        :rtype: str
        """
        return self._vhost

    @vhost.setter
    def vhost(self, vhost):
        """Sets the vhost of this NotificationSchemaAmqppublish.

        Virtual host of amqp on which connection has to be instantiated  # noqa: E501

        :param vhost: The vhost of this NotificationSchemaAmqppublish.  # noqa: E501
        :type: str
        """

        self._vhost = vhost

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NotificationSchemaAmqppublish, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotificationSchemaAmqppublish):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TopicSchemaLocateresource(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'label_as': 'str',
        'resource': 'str',
        'where': 'TopicSchemaWhere',
        'with_capture_group': 'list[TopicSchemaWithcapturegroup]'
    }

    attribute_map = {
        'label_as': 'label-as',
        'resource': 'resource',
        'where': 'where',
        'with_capture_group': 'with-capture-group'
    }

    def __init__(self, label_as=None, resource=None, where=None, with_capture_group=None):  # noqa: E501
        """TopicSchemaLocateresource - a model defined in Swagger"""  # noqa: E501

        self._label_as = None
        self._resource = None
        self._where = None
        self._with_capture_group = None
        self.discriminator = None

        self.label_as = label_as
        self.resource = resource
        if where is not None:
            self.where = where
        if with_capture_group is not None:
            self.with_capture_group = with_capture_group

    @property
    def label_as(self):
        """Gets the label_as of this TopicSchemaLocateresource.  # noqa: E501


        :return: The label_as of this TopicSchemaLocateresource.  # noqa: E501
        :rtype: str
        """
        return self._label_as

    @label_as.setter
    def label_as(self, label_as):
        """Sets the label_as of this TopicSchemaLocateresource.


        :param label_as: The label_as of this TopicSchemaLocateresource.  # noqa: E501
        :type: str
        """
        if label_as is None:
            raise ValueError("Invalid value for `label_as`, must not be `None`")  # noqa: E501
        if label_as is not None and len(label_as) > 64:
            raise ValueError("Invalid value for `label_as`, length must be less than or equal to `64`")  # noqa: E501
        if label_as is not None and len(label_as) < 1:
            raise ValueError("Invalid value for `label_as`, length must be greater than or equal to `1`")  # noqa: E501
        if label_as is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9-]*$', label_as):  # noqa: E501
            raise ValueError(r"Invalid value for `label_as`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9-]*$/`")  # noqa: E501

        self._label_as = label_as

    @property
    def resource(self):
        """Gets the resource of this TopicSchemaLocateresource.  # noqa: E501

        Name of the resource which needs to looped over. Format: <optional-idetifier followed by :><topic-name/rule-name>. Should be of pattern ([a-zA-Z][a-zA-Z0-9-]*:)?[a-z][a-z-]*(\\.{1}[a-z0-9-]+)*/[a-z][a-z0-9-]*.  # noqa: E501

        :return: The resource of this TopicSchemaLocateresource.  # noqa: E501
        :rtype: str
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """Sets the resource of this TopicSchemaLocateresource.

        Name of the resource which needs to looped over. Format: <optional-idetifier followed by :><topic-name/rule-name>. Should be of pattern ([a-zA-Z][a-zA-Z0-9-]*:)?[a-z][a-z-]*(\\.{1}[a-z0-9-]+)*/[a-z][a-z0-9-]*.  # noqa: E501

        :param resource: The resource of this TopicSchemaLocateresource.  # noqa: E501
        :type: str
        """
        if resource is None:
            raise ValueError("Invalid value for `resource`, must not be `None`")  # noqa: E501
        if resource is not None and not re.search(r'^([a-zA-Z][a-zA-Z0-9-]*:)?[a-z][a-z-]*(\\.{1}[a-z0-9-]+)*\/[a-z][a-z0-9-]*$', resource):  # noqa: E501
            raise ValueError(r"Invalid value for `resource`, must be a follow pattern or equal to `/^([a-zA-Z][a-zA-Z0-9-]*:)?[a-z][a-z-]*(\\.{1}[a-z0-9-]+)*\/[a-z][a-z0-9-]*$/`")  # noqa: E501

        self._resource = resource

    @property
    def where(self):
        """Gets the where of this TopicSchemaLocateresource.  # noqa: E501


        :return: The where of this TopicSchemaLocateresource.  # noqa: E501
        :rtype: TopicSchemaWhere
        """
        return self._where

    @where.setter
    def where(self, where):
        """Sets the where of this TopicSchemaLocateresource.


        :param where: The where of this TopicSchemaLocateresource.  # noqa: E501
        :type: TopicSchemaWhere
        """

        self._where = where

    @property
    def with_capture_group(self):
        """Gets the with_capture_group of this TopicSchemaLocateresource.  # noqa: E501


        :return: The with_capture_group of this TopicSchemaLocateresource.  # noqa: E501
        :rtype: list[TopicSchemaWithcapturegroup]
        """
        return self._with_capture_group

    @with_capture_group.setter
    def with_capture_group(self, with_capture_group):
        """Sets the with_capture_group of this TopicSchemaLocateresource.


        :param with_capture_group: The with_capture_group of this TopicSchemaLocateresource.  # noqa: E501
        :type: list[TopicSchemaWithcapturegroup]
        """

        self._with_capture_group = with_capture_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TopicSchemaLocateresource, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TopicSchemaLocateresource):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RollupsummarizationSchemaDatarolluporder(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'instance_id': 'str',
        'interval': 'str',
        'retention_policy': 'str'
    }

    attribute_map = {
        'instance_id': 'instance-id',
        'interval': 'interval',
        'retention_policy': 'retention-policy'
    }

    def __init__(self, instance_id=None, interval=None, retention_policy=None):  # noqa: E501
        """RollupsummarizationSchemaDatarolluporder - a model defined in Swagger"""  # noqa: E501

        self._instance_id = None
        self._interval = None
        self._retention_policy = None
        self.discriminator = None

        self.instance_id = instance_id
        self.interval = interval
        if retention_policy is not None:
            self.retention_policy = retention_policy

    @property
    def instance_id(self):
        """Gets the instance_id of this RollupsummarizationSchemaDatarolluporder.  # noqa: E501

        Instance-id/aggregation-id of data rollup summarization instance. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The instance_id of this RollupsummarizationSchemaDatarolluporder.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this RollupsummarizationSchemaDatarolluporder.

        Instance-id/aggregation-id of data rollup summarization instance. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :param instance_id: The instance_id of this RollupsummarizationSchemaDatarolluporder.  # noqa: E501
        :type: str
        """
        if instance_id is None:
            raise ValueError("Invalid value for `instance_id`, must not be `None`")  # noqa: E501
        if instance_id is not None and len(instance_id) > 64:
            raise ValueError("Invalid value for `instance_id`, length must be less than or equal to `64`")  # noqa: E501
        if instance_id is not None and len(instance_id) < 1:
            raise ValueError("Invalid value for `instance_id`, length must be greater than or equal to `1`")  # noqa: E501
        if instance_id is not None and not re.search(r'^[a-zA-Z0-9]([a-zA-Z0-9_-]*\\.*)*$', instance_id):  # noqa: E501
            raise ValueError(r"Invalid value for `instance_id`, must be a follow pattern or equal to `/^[a-zA-Z0-9]([a-zA-Z0-9_-]*\\.*)*$/`")  # noqa: E501

        self._instance_id = instance_id

    @property
    def interval(self):
        """Gets the interval of this RollupsummarizationSchemaDatarolluporder.  # noqa: E501

        Time interval for the data roll up to occur( m/h/d/w representing minutes/hours/days/weeks. Min value: 30m, Max value: 52w )   # noqa: E501

        :return: The interval of this RollupsummarizationSchemaDatarolluporder.  # noqa: E501
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this RollupsummarizationSchemaDatarolluporder.

        Time interval for the data roll up to occur( m/h/d/w representing minutes/hours/days/weeks. Min value: 30m, Max value: 52w )   # noqa: E501

        :param interval: The interval of this RollupsummarizationSchemaDatarolluporder.  # noqa: E501
        :type: str
        """
        if interval is None:
            raise ValueError("Invalid value for `interval`, must not be `None`")  # noqa: E501
        if interval is not None and not re.search(r'^[1-9][0-9]*[mhdw]$', interval):  # noqa: E501
            raise ValueError(r"Invalid value for `interval`, must be a follow pattern or equal to `/^[1-9][0-9]*[mhdw]$/`")  # noqa: E501

        self._interval = interval

    @property
    def retention_policy(self):
        """Gets the retention_policy of this RollupsummarizationSchemaDatarolluporder.  # noqa: E501

        Retention policy for the data-rollup instance. If not configured, default retention policy will be considered  # noqa: E501

        :return: The retention_policy of this RollupsummarizationSchemaDatarolluporder.  # noqa: E501
        :rtype: str
        """
        return self._retention_policy

    @retention_policy.setter
    def retention_policy(self, retention_policy):
        """Sets the retention_policy of this RollupsummarizationSchemaDatarolluporder.

        Retention policy for the data-rollup instance. If not configured, default retention policy will be considered  # noqa: E501

        :param retention_policy: The retention_policy of this RollupsummarizationSchemaDatarolluporder.  # noqa: E501
        :type: str
        """
        if retention_policy is not None and len(retention_policy) > 64:
            raise ValueError("Invalid value for `retention_policy`, length must be less than or equal to `64`")  # noqa: E501
        if retention_policy is not None and len(retention_policy) < 1:
            raise ValueError("Invalid value for `retention_policy`, length must be greater than or equal to `1`")  # noqa: E501
        if retention_policy is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', retention_policy):  # noqa: E501
            raise ValueError(r"Invalid value for `retention_policy`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._retention_policy = retention_policy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RollupsummarizationSchemaDatarolluporder, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RollupsummarizationSchemaDatarolluporder):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaWhenDoesnotmatchwith(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'all': 'list[object]',
        'any': 'list[object]',
        'ignore_case': 'list[object]',
        'left_operand': 'str',
        'right_operand': 'str',
        'time_range': 'str'
    }

    attribute_map = {
        'all': 'all',
        'any': 'any',
        'ignore_case': 'ignore-case',
        'left_operand': 'left-operand',
        'right_operand': 'right-operand',
        'time_range': 'time-range'
    }

    def __init__(self, all=None, any=None, ignore_case=None, left_operand=None, right_operand=None, time_range=None):  # noqa: E501
        """RuleSchemaWhenDoesnotmatchwith - a model defined in Swagger"""  # noqa: E501

        self._all = None
        self._any = None
        self._ignore_case = None
        self._left_operand = None
        self._right_operand = None
        self._time_range = None
        self.discriminator = None

        if all is not None:
            self.all = all
        if any is not None:
            self.any = any
        if ignore_case is not None:
            self.ignore_case = ignore_case
        self.left_operand = left_operand
        self.right_operand = right_operand
        if time_range is not None:
            self.time_range = time_range

    @property
    def all(self):
        """Gets the all of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501

        With this flag, result is set to True only if all the data matches the given condition  # noqa: E501

        :return: The all of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501
        :rtype: list[object]
        """
        return self._all

    @all.setter
    def all(self, all):
        """Sets the all of this RuleSchemaWhenDoesnotmatchwith.

        With this flag, result is set to True only if all the data matches the given condition  # noqa: E501

        :param all: The all of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501
        :type: list[object]
        """

        self._all = all

    @property
    def any(self):
        """Gets the any of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501

        With this flag, result is set to True if any one of the data matches the condition  # noqa: E501

        :return: The any of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501
        :rtype: list[object]
        """
        return self._any

    @any.setter
    def any(self, any):
        """Sets the any of this RuleSchemaWhenDoesnotmatchwith.

        With this flag, result is set to True if any one of the data matches the condition  # noqa: E501

        :param any: The any of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501
        :type: list[object]
        """

        self._any = any

    @property
    def ignore_case(self):
        """Gets the ignore_case of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501

        Flag to ignore case while matching the string  # noqa: E501

        :return: The ignore_case of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501
        :rtype: list[object]
        """
        return self._ignore_case

    @ignore_case.setter
    def ignore_case(self, ignore_case):
        """Sets the ignore_case of this RuleSchemaWhenDoesnotmatchwith.

        Flag to ignore case while matching the string  # noqa: E501

        :param ignore_case: The ignore_case of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501
        :type: list[object]
        """

        self._ignore_case = ignore_case

    @property
    def left_operand(self):
        """Gets the left_operand of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501

        Left operand. This is the string in which we have to match the expression.  # noqa: E501

        :return: The left_operand of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501
        :rtype: str
        """
        return self._left_operand

    @left_operand.setter
    def left_operand(self, left_operand):
        """Sets the left_operand of this RuleSchemaWhenDoesnotmatchwith.

        Left operand. This is the string in which we have to match the expression.  # noqa: E501

        :param left_operand: The left_operand of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501
        :type: str
        """
        if left_operand is None:
            raise ValueError("Invalid value for `left_operand`, must not be `None`")  # noqa: E501

        self._left_operand = left_operand

    @property
    def right_operand(self):
        """Gets the right_operand of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501

        Right operand. This is the match expression.  # noqa: E501

        :return: The right_operand of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501
        :rtype: str
        """
        return self._right_operand

    @right_operand.setter
    def right_operand(self, right_operand):
        """Sets the right_operand of this RuleSchemaWhenDoesnotmatchwith.

        Right operand. This is the match expression.  # noqa: E501

        :param right_operand: The right_operand of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501
        :type: str
        """
        if right_operand is None:
            raise ValueError("Invalid value for `right_operand`, must not be `None`")  # noqa: E501

        self._right_operand = right_operand

    @property
    def time_range(self):
        """Gets the time_range of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501

        How much back in time should we look for data. Specify positive integer followed by s/m/h/d/w/y/o representing seconds/minutes/hours/days/weeks/years/offset. Eg: 2s  # noqa: E501

        :return: The time_range of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501
        :rtype: str
        """
        return self._time_range

    @time_range.setter
    def time_range(self, time_range):
        """Sets the time_range of this RuleSchemaWhenDoesnotmatchwith.

        How much back in time should we look for data. Specify positive integer followed by s/m/h/d/w/y/o representing seconds/minutes/hours/days/weeks/years/offset. Eg: 2s  # noqa: E501

        :param time_range: The time_range of this RuleSchemaWhenDoesnotmatchwith.  # noqa: E501
        :type: str
        """
        if time_range is not None and not re.search(r'^[1-9][0-9]*(\\.[0-9]+)?(o|s|m|h|d|w|y|offset)$', time_range):  # noqa: E501
            raise ValueError(r"Invalid value for `time_range`, must be a follow pattern or equal to `/^[1-9][0-9]*(\\.[0-9]+)?(o|s|m|h|d|w|y|offset)$/`")  # noqa: E501

        self._time_range = time_range

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaWhenDoesnotmatchwith, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaWhenDoesnotmatchwith):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PanelDataSchema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'add_group_by_tag': 'PanelDataSchemaAddGroupByTag',
        'add_where_condition': 'PanelDataSchemaAddWhereCondition',
        'change_where_key_field': 'PanelDataSchemaChangeWhereKeyField',
        'group_by_fill': 'PanelDataSchemaGroupByFill',
        'group_by_time': 'PanelDataSchemaGroupByTime',
        'group_type': 'str',
        'selected_aggregation': 'PanelDataSchemaSelectedAggregation',
        'selected_device': 'PanelDataSchemaSelectedDevice',
        'selected_dropdown': 'PanelDataSchemaSelectedDropdown',
        'selected_field': 'PanelDataSchemaSelectedField',
        'selected_group': 'PanelDataSchemaSelectedGroup',
        'selected_logical_operator': 'PanelDataSchemaSelectedLogicalOperator',
        'selected_topic': 'PanelDataSchemaSelectedTopic',
        'selected_transformation': 'PanelDataSchemaSelectedTransformation'
    }

    attribute_map = {
        'add_group_by_tag': 'addGroupByTag',
        'add_where_condition': 'addWhereCondition',
        'change_where_key_field': 'changeWhereKeyField',
        'group_by_fill': 'groupByFill',
        'group_by_time': 'groupByTime',
        'group_type': 'groupType',
        'selected_aggregation': 'selectedAggregation',
        'selected_device': 'selectedDevice',
        'selected_dropdown': 'selectedDropdown',
        'selected_field': 'selectedField',
        'selected_group': 'selectedGroup',
        'selected_logical_operator': 'selectedLogicalOperator',
        'selected_topic': 'selectedTopic',
        'selected_transformation': 'selectedTransformation'
    }

    def __init__(self, add_group_by_tag=None, add_where_condition=None, change_where_key_field=None, group_by_fill=None, group_by_time=None, group_type=None, selected_aggregation=None, selected_device=None, selected_dropdown=None, selected_field=None, selected_group=None, selected_logical_operator=None, selected_topic=None, selected_transformation=None):  # noqa: E501
        """PanelDataSchema - a model defined in Swagger"""  # noqa: E501

        self._add_group_by_tag = None
        self._add_where_condition = None
        self._change_where_key_field = None
        self._group_by_fill = None
        self._group_by_time = None
        self._group_type = None
        self._selected_aggregation = None
        self._selected_device = None
        self._selected_dropdown = None
        self._selected_field = None
        self._selected_group = None
        self._selected_logical_operator = None
        self._selected_topic = None
        self._selected_transformation = None
        self.discriminator = None

        if add_group_by_tag is not None:
            self.add_group_by_tag = add_group_by_tag
        if add_where_condition is not None:
            self.add_where_condition = add_where_condition
        if change_where_key_field is not None:
            self.change_where_key_field = change_where_key_field
        if group_by_fill is not None:
            self.group_by_fill = group_by_fill
        if group_by_time is not None:
            self.group_by_time = group_by_time
        if group_type is not None:
            self.group_type = group_type
        if selected_aggregation is not None:
            self.selected_aggregation = selected_aggregation
        if selected_device is not None:
            self.selected_device = selected_device
        if selected_dropdown is not None:
            self.selected_dropdown = selected_dropdown
        if selected_field is not None:
            self.selected_field = selected_field
        if selected_group is not None:
            self.selected_group = selected_group
        if selected_logical_operator is not None:
            self.selected_logical_operator = selected_logical_operator
        if selected_topic is not None:
            self.selected_topic = selected_topic
        if selected_transformation is not None:
            self.selected_transformation = selected_transformation

    @property
    def add_group_by_tag(self):
        """Gets the add_group_by_tag of this PanelDataSchema.  # noqa: E501


        :return: The add_group_by_tag of this PanelDataSchema.  # noqa: E501
        :rtype: PanelDataSchemaAddGroupByTag
        """
        return self._add_group_by_tag

    @add_group_by_tag.setter
    def add_group_by_tag(self, add_group_by_tag):
        """Sets the add_group_by_tag of this PanelDataSchema.


        :param add_group_by_tag: The add_group_by_tag of this PanelDataSchema.  # noqa: E501
        :type: PanelDataSchemaAddGroupByTag
        """

        self._add_group_by_tag = add_group_by_tag

    @property
    def add_where_condition(self):
        """Gets the add_where_condition of this PanelDataSchema.  # noqa: E501


        :return: The add_where_condition of this PanelDataSchema.  # noqa: E501
        :rtype: PanelDataSchemaAddWhereCondition
        """
        return self._add_where_condition

    @add_where_condition.setter
    def add_where_condition(self, add_where_condition):
        """Sets the add_where_condition of this PanelDataSchema.


        :param add_where_condition: The add_where_condition of this PanelDataSchema.  # noqa: E501
        :type: PanelDataSchemaAddWhereCondition
        """

        self._add_where_condition = add_where_condition

    @property
    def change_where_key_field(self):
        """Gets the change_where_key_field of this PanelDataSchema.  # noqa: E501


        :return: The change_where_key_field of this PanelDataSchema.  # noqa: E501
        :rtype: PanelDataSchemaChangeWhereKeyField
        """
        return self._change_where_key_field

    @change_where_key_field.setter
    def change_where_key_field(self, change_where_key_field):
        """Sets the change_where_key_field of this PanelDataSchema.


        :param change_where_key_field: The change_where_key_field of this PanelDataSchema.  # noqa: E501
        :type: PanelDataSchemaChangeWhereKeyField
        """

        self._change_where_key_field = change_where_key_field

    @property
    def group_by_fill(self):
        """Gets the group_by_fill of this PanelDataSchema.  # noqa: E501


        :return: The group_by_fill of this PanelDataSchema.  # noqa: E501
        :rtype: PanelDataSchemaGroupByFill
        """
        return self._group_by_fill

    @group_by_fill.setter
    def group_by_fill(self, group_by_fill):
        """Sets the group_by_fill of this PanelDataSchema.


        :param group_by_fill: The group_by_fill of this PanelDataSchema.  # noqa: E501
        :type: PanelDataSchemaGroupByFill
        """

        self._group_by_fill = group_by_fill

    @property
    def group_by_time(self):
        """Gets the group_by_time of this PanelDataSchema.  # noqa: E501


        :return: The group_by_time of this PanelDataSchema.  # noqa: E501
        :rtype: PanelDataSchemaGroupByTime
        """
        return self._group_by_time

    @group_by_time.setter
    def group_by_time(self, group_by_time):
        """Sets the group_by_time of this PanelDataSchema.


        :param group_by_time: The group_by_time of this PanelDataSchema.  # noqa: E501
        :type: PanelDataSchemaGroupByTime
        """

        self._group_by_time = group_by_time

    @property
    def group_type(self):
        """Gets the group_type of this PanelDataSchema.  # noqa: E501

        Group type(device/network)  # noqa: E501

        :return: The group_type of this PanelDataSchema.  # noqa: E501
        :rtype: str
        """
        return self._group_type

    @group_type.setter
    def group_type(self, group_type):
        """Sets the group_type of this PanelDataSchema.

        Group type(device/network)  # noqa: E501

        :param group_type: The group_type of this PanelDataSchema.  # noqa: E501
        :type: str
        """

        self._group_type = group_type

    @property
    def selected_aggregation(self):
        """Gets the selected_aggregation of this PanelDataSchema.  # noqa: E501


        :return: The selected_aggregation of this PanelDataSchema.  # noqa: E501
        :rtype: PanelDataSchemaSelectedAggregation
        """
        return self._selected_aggregation

    @selected_aggregation.setter
    def selected_aggregation(self, selected_aggregation):
        """Sets the selected_aggregation of this PanelDataSchema.


        :param selected_aggregation: The selected_aggregation of this PanelDataSchema.  # noqa: E501
        :type: PanelDataSchemaSelectedAggregation
        """

        self._selected_aggregation = selected_aggregation

    @property
    def selected_device(self):
        """Gets the selected_device of this PanelDataSchema.  # noqa: E501


        :return: The selected_device of this PanelDataSchema.  # noqa: E501
        :rtype: PanelDataSchemaSelectedDevice
        """
        return self._selected_device

    @selected_device.setter
    def selected_device(self, selected_device):
        """Sets the selected_device of this PanelDataSchema.


        :param selected_device: The selected_device of this PanelDataSchema.  # noqa: E501
        :type: PanelDataSchemaSelectedDevice
        """

        self._selected_device = selected_device

    @property
    def selected_dropdown(self):
        """Gets the selected_dropdown of this PanelDataSchema.  # noqa: E501


        :return: The selected_dropdown of this PanelDataSchema.  # noqa: E501
        :rtype: PanelDataSchemaSelectedDropdown
        """
        return self._selected_dropdown

    @selected_dropdown.setter
    def selected_dropdown(self, selected_dropdown):
        """Sets the selected_dropdown of this PanelDataSchema.


        :param selected_dropdown: The selected_dropdown of this PanelDataSchema.  # noqa: E501
        :type: PanelDataSchemaSelectedDropdown
        """

        self._selected_dropdown = selected_dropdown

    @property
    def selected_field(self):
        """Gets the selected_field of this PanelDataSchema.  # noqa: E501


        :return: The selected_field of this PanelDataSchema.  # noqa: E501
        :rtype: PanelDataSchemaSelectedField
        """
        return self._selected_field

    @selected_field.setter
    def selected_field(self, selected_field):
        """Sets the selected_field of this PanelDataSchema.


        :param selected_field: The selected_field of this PanelDataSchema.  # noqa: E501
        :type: PanelDataSchemaSelectedField
        """

        self._selected_field = selected_field

    @property
    def selected_group(self):
        """Gets the selected_group of this PanelDataSchema.  # noqa: E501


        :return: The selected_group of this PanelDataSchema.  # noqa: E501
        :rtype: PanelDataSchemaSelectedGroup
        """
        return self._selected_group

    @selected_group.setter
    def selected_group(self, selected_group):
        """Sets the selected_group of this PanelDataSchema.


        :param selected_group: The selected_group of this PanelDataSchema.  # noqa: E501
        :type: PanelDataSchemaSelectedGroup
        """

        self._selected_group = selected_group

    @property
    def selected_logical_operator(self):
        """Gets the selected_logical_operator of this PanelDataSchema.  # noqa: E501


        :return: The selected_logical_operator of this PanelDataSchema.  # noqa: E501
        :rtype: PanelDataSchemaSelectedLogicalOperator
        """
        return self._selected_logical_operator

    @selected_logical_operator.setter
    def selected_logical_operator(self, selected_logical_operator):
        """Sets the selected_logical_operator of this PanelDataSchema.


        :param selected_logical_operator: The selected_logical_operator of this PanelDataSchema.  # noqa: E501
        :type: PanelDataSchemaSelectedLogicalOperator
        """

        self._selected_logical_operator = selected_logical_operator

    @property
    def selected_topic(self):
        """Gets the selected_topic of this PanelDataSchema.  # noqa: E501


        :return: The selected_topic of this PanelDataSchema.  # noqa: E501
        :rtype: PanelDataSchemaSelectedTopic
        """
        return self._selected_topic

    @selected_topic.setter
    def selected_topic(self, selected_topic):
        """Sets the selected_topic of this PanelDataSchema.


        :param selected_topic: The selected_topic of this PanelDataSchema.  # noqa: E501
        :type: PanelDataSchemaSelectedTopic
        """

        self._selected_topic = selected_topic

    @property
    def selected_transformation(self):
        """Gets the selected_transformation of this PanelDataSchema.  # noqa: E501


        :return: The selected_transformation of this PanelDataSchema.  # noqa: E501
        :rtype: PanelDataSchemaSelectedTransformation
        """
        return self._selected_transformation

    @selected_transformation.setter
    def selected_transformation(self, selected_transformation):
        """Sets the selected_transformation of this PanelDataSchema.


        :param selected_transformation: The selected_transformation of this PanelDataSchema.  # noqa: E501
        :type: PanelDataSchemaSelectedTransformation
        """

        self._selected_transformation = selected_transformation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PanelDataSchema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PanelDataSchema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DeviceSchema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'authentication': 'DevicegroupSchemaAuthentication',
        'description': 'str',
        'device_id': 'str',
        'uuid': 'str',
        'flow': 'DeviceSchemaFlow',
        'host': 'str',
        'i_agent': 'DeviceSchemaIAgent',
        'open_config': 'DeviceSchemaOpenconfig',
        'server_monitoring': 'DeviceSchemaOpenconfig',
        'outbound_ssh': 'DeviceSchemaOutboundssh',
        'owner': 'str',
        'snmp': 'DeviceSchemaSnmp',
        'syslog': 'DeviceSchemaSyslog',
        'tagging_profile': 'list[str]',
        'timezone': 'str',
        'system_id': 'str',
        'use_ingest_receive_time': 'list[object]',
        'variable': 'list[DeviceSchemaVariable]',
        'vendor': 'DeviceSchemaVendor'
    }

    attribute_map = {
        'authentication': 'authentication',
        'description': 'description',
        'device_id': 'device-id',
        'uuid': 'uuid',
        'flow': 'flow',
        'host': 'host',
        'i_agent': 'iAgent',
        'open_config': 'open-config',
        'server_monitoring': 'server-monitoring',
        'outbound_ssh': 'outbound-ssh',
        'owner': 'owner',
        'snmp': 'snmp',
        'syslog': 'syslog',
        'tagging_profile': 'tagging-profile',
        'timezone': 'timezone',
        'system_id': 'system-id',
        'use_ingest_receive_time': 'use-ingest-receive-time',
        'variable': 'variable',
        'vendor': 'vendor'
    }

    def __init__(self, authentication=None, description=None, device_id=None, uuid=None, flow=None, host=None, i_agent=None, open_config=None, server_monitoring=None, outbound_ssh=None, owner=None, snmp=None, syslog=None, tagging_profile=None, timezone=None, system_id=None, use_ingest_receive_time=None, variable=None, vendor=None):  # noqa: E501
        """DeviceSchema - a model defined in Swagger"""  # noqa: E501

        self._authentication = None
        self._description = None
        self._device_id = None
        self._uuid = None
        self._flow = None
        self._host = None
        self._i_agent = None
        self._open_config = None
        self._server_monitoring = None
        self._outbound_ssh = None
        self._owner = None
        self._snmp = None
        self._syslog = None
        self._tagging_profile = None
        self._timezone = None
        self._system_id = None
        self._use_ingest_receive_time = None
        self._variable = None
        self._vendor = None
        self.discriminator = None

        if authentication is not None:
            self.authentication = authentication
        if description is not None:
            self.description = description
        self.device_id = device_id
        if uuid is not None:
            self.uuid = uuid
        if flow is not None:
            self.flow = flow
        self.host = host
        if i_agent is not None:
            self.i_agent = i_agent
        if open_config is not None:
            self.open_config = open_config
        if server_monitoring is not None:
            self.server_monitoring = server_monitoring
        if outbound_ssh is not None:
            self.outbound_ssh = outbound_ssh
        if owner is not None:
            self.owner = owner
        if snmp is not None:
            self.snmp = snmp
        if syslog is not None:
            self.syslog = syslog
        if tagging_profile is not None:
            self.tagging_profile = tagging_profile
        if timezone is not None:
            self.timezone = timezone
        if system_id is not None:
            self.system_id = system_id
        if use_ingest_receive_time is not None:
            self.use_ingest_receive_time = use_ingest_receive_time
        if variable is not None:
            self.variable = variable
        if vendor is not None:
            self.vendor = vendor

    @property
    def authentication(self):
        """Gets the authentication of this DeviceSchema.  # noqa: E501


        :return: The authentication of this DeviceSchema.  # noqa: E501
        :rtype: DevicegroupSchemaAuthentication
        """
        return self._authentication

    @authentication.setter
    def authentication(self, authentication):
        """Sets the authentication of this DeviceSchema.


        :param authentication: The authentication of this DeviceSchema.  # noqa: E501
        :type: DevicegroupSchemaAuthentication
        """

        self._authentication = authentication

    @property
    def description(self):
        """Gets the description of this DeviceSchema.  # noqa: E501

        Description about the device  # noqa: E501

        :return: The description of this DeviceSchema.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DeviceSchema.

        Description about the device  # noqa: E501

        :param description: The description of this DeviceSchema.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def device_id(self):
        """Gets the device_id of this DeviceSchema.  # noqa: E501

        Identifier for the device. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The device_id of this DeviceSchema.  # noqa: E501
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this DeviceSchema.

        Identifier for the device. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :param device_id: The device_id of this DeviceSchema.  # noqa: E501
        :type: str
        """
        if device_id is None:
            raise ValueError("Invalid value for `device_id`, must not be `None`")  # noqa: E501
        if device_id is not None and len(device_id) > 64:
            raise ValueError("Invalid value for `device_id`, length must be less than or equal to `64`")  # noqa: E501
        if device_id is not None and not re.search('^[a-zA-Z0-9]([a-zA-Z0-9_-]*\\.*)*$', device_id):  # noqa: E501
            raise ValueError("Invalid value for `device_id`, must be a follow pattern or equal to `/^[a-zA-Z0-9]([a-zA-Z0-9_-]*\\.*)*$/`")  # noqa: E501

        self._device_id = device_id

    @property
    def uuid(self):
        """Gets the uuid of this DeviceSchema.  # noqa: E501

        EMS: uuid of the EMS-advertised device  # noqa: E501

        :return: The uuid of this DeviceSchema.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this DeviceSchema.

        EMS: uuid of the EMS-advertised device  # noqa: E501

        :param uuid: The uuid of this DeviceSchema.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def flow(self):
        """Gets the flow of this DeviceSchema.  # noqa: E501


        :return: The flow of this DeviceSchema.  # noqa: E501
        :rtype: DeviceSchemaFlow
        """
        return self._flow

    @flow.setter
    def flow(self, flow):
        """Sets the flow of this DeviceSchema.


        :param flow: The flow of this DeviceSchema.  # noqa: E501
        :type: DeviceSchemaFlow
        """

        self._flow = flow

    @property
    def host(self):
        """Gets the host of this DeviceSchema.  # noqa: E501

        Name or IP of the device  # noqa: E501

        :return: The host of this DeviceSchema.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this DeviceSchema.

        Name or IP of the device  # noqa: E501

        :param host: The host of this DeviceSchema.  # noqa: E501
        :type: str
        """
        if host is None:
            raise ValueError("Invalid value for `host`, must not be `None`")  # noqa: E501
        if host is not None and len(host) > 255:
            raise ValueError("Invalid value for `host`, length must be less than or equal to `255`")  # noqa: E501
        if host is not None and len(host) < 1:
            raise ValueError("Invalid value for `host`, length must be greater than or equal to `1`")  # noqa: E501

        self._host = host

    @property
    def i_agent(self):
        """Gets the i_agent of this DeviceSchema.  # noqa: E501


        :return: The i_agent of this DeviceSchema.  # noqa: E501
        :rtype: DeviceSchemaIAgent
        """
        return self._i_agent

    @i_agent.setter
    def i_agent(self, i_agent):
        """Sets the i_agent of this DeviceSchema.


        :param i_agent: The i_agent of this DeviceSchema.  # noqa: E501
        :type: DeviceSchemaIAgent
        """

        self._i_agent = i_agent

    @property
    def open_config(self):
        """Gets the open_config of this DeviceSchema.  # noqa: E501


        :return: The open_config of this DeviceSchema.  # noqa: E501
        :rtype: DeviceSchemaOpenconfig
        """
        return self._open_config

    @open_config.setter
    def open_config(self, open_config):
        """Sets the open_config of this DeviceSchema.


        :param open_config: The open_config of this DeviceSchema.  # noqa: E501
        :type: DeviceSchemaOpenconfig
        """

        self._open_config = open_config

    @property
    def server_monitoring(self):
        """Gets the server_monitoring of this DeviceSchema.  # noqa: E501


        :return: The server_monitoring of this DeviceSchema.  # noqa: E501
        :rtype: DeviceSchemaOpenconfig
        """
        return self._server_monitoring

    @server_monitoring.setter
    def server_monitoring(self, server_monitoring):
        """Sets the server_monitoring of this DeviceSchema.


        :param server_monitoring: The server_monitoring of this DeviceSchema.  # noqa: E501
        :type: DeviceSchemaOpenconfig
        """

        self._server_monitoring = server_monitoring

    @property
    def outbound_ssh(self):
        """Gets the outbound_ssh of this DeviceSchema.  # noqa: E501


        :return: The outbound_ssh of this DeviceSchema.  # noqa: E501
        :rtype: DeviceSchemaOutboundssh
        """
        return self._outbound_ssh

    @outbound_ssh.setter
    def outbound_ssh(self, outbound_ssh):
        """Sets the outbound_ssh of this DeviceSchema.


        :param outbound_ssh: The outbound_ssh of this DeviceSchema.  # noqa: E501
        :type: DeviceSchemaOutboundssh
        """

        self._outbound_ssh = outbound_ssh

    @property
    def owner(self):
        """Gets the owner of this DeviceSchema.  # noqa: E501

        Owner of the device: this is a read-only attribute and should not be added to the request payload, value if added will be discarded.  # noqa: E501

        :return: The owner of this DeviceSchema.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this DeviceSchema.

        Owner of the device: this is a read-only attribute and should not be added to the request payload, value if added will be discarded.  # noqa: E501

        :param owner: The owner of this DeviceSchema.  # noqa: E501
        :type: str
        """

        self._owner = owner

    @property
    def snmp(self):
        """Gets the snmp of this DeviceSchema.  # noqa: E501


        :return: The snmp of this DeviceSchema.  # noqa: E501
        :rtype: DeviceSchemaSnmp
        """
        return self._snmp

    @snmp.setter
    def snmp(self, snmp):
        """Sets the snmp of this DeviceSchema.


        :param snmp: The snmp of this DeviceSchema.  # noqa: E501
        :type: DeviceSchemaSnmp
        """

        self._snmp = snmp

    @property
    def syslog(self):
        """Gets the syslog of this DeviceSchema.  # noqa: E501


        :return: The syslog of this DeviceSchema.  # noqa: E501
        :rtype: DeviceSchemaSyslog
        """
        return self._syslog

    @syslog.setter
    def syslog(self, syslog):
        """Sets the syslog of this DeviceSchema.


        :param syslog: The syslog of this DeviceSchema.  # noqa: E501
        :type: DeviceSchemaSyslog
        """

        self._syslog = syslog

    @property
    def tagging_profile(self):
        """Gets the tagging_profile of this DeviceSchema.  # noqa: E501


        :return: The tagging_profile of this DeviceSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._tagging_profile

    @tagging_profile.setter
    def tagging_profile(self, tagging_profile):
        """Sets the tagging_profile of this DeviceSchema.


        :param tagging_profile: The tagging_profile of this DeviceSchema.  # noqa: E501
        :type: list[str]
        """

        self._tagging_profile = tagging_profile

    @property
    def timezone(self):
        """Gets the timezone of this DeviceSchema.  # noqa: E501

        Timezone in the format +/-hh:mm, Example: -08:00  # noqa: E501

        :return: The timezone of this DeviceSchema.  # noqa: E501
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """Sets the timezone of this DeviceSchema.

        Timezone in the format +/-hh:mm, Example: -08:00  # noqa: E501

        :param timezone: The timezone of this DeviceSchema.  # noqa: E501
        :type: str
        """
        if timezone is not None and not re.search(r'^((\\+|-)((([0-1][0-9])|(2[0-3])):([0-5][0-9])))$', timezone):  # noqa: E501
            raise ValueError(r"Invalid value for `timezone`, must be a follow pattern or equal to `/^((\\+|-)((([0-1][0-9])|(2[0-3])):([0-5][0-9])))$/`")  # noqa: E501

        self._timezone = timezone

    @property
    def system_id(self):
        """Gets the system_id of this DeviceSchema.  # noqa: E501

        ID which is sent in the JTI UDP messages  # noqa: E501

        :return: The system_id of this DeviceSchema.  # noqa: E501
        :rtype: str
        """
        return self._system_id

    @system_id.setter
    def system_id(self, system_id):
        """Sets the system_id of this DeviceSchema.

        ID which is sent in the JTI UDP messages  # noqa: E501

        :param system_id: The system_id of this DeviceSchema.  # noqa: E501
        :type: str
        """

        self._system_id = system_id

    @property
    def use_ingest_receive_time(self):
        """Gets the use_ingest_receive_time of this DeviceSchema.  # noqa: E501

        Enable using ingest receive time in formulas like elapsed-time and rate-of-change  # noqa: E501

        :return: The use_ingest_receive_time of this DeviceSchema.  # noqa: E501
        :rtype: list[object]
        """
        return self._use_ingest_receive_time

    @use_ingest_receive_time.setter
    def use_ingest_receive_time(self, use_ingest_receive_time):
        """Sets the use_ingest_receive_time of this DeviceSchema.

        Enable using ingest receive time in formulas like elapsed-time and rate-of-change  # noqa: E501

        :param use_ingest_receive_time: The use_ingest_receive_time of this DeviceSchema.  # noqa: E501
        :type: list[object]
        """

        self._use_ingest_receive_time = use_ingest_receive_time

    @property
    def variable(self):
        """Gets the variable of this DeviceSchema.  # noqa: E501

        Playbook variable configuration  # noqa: E501

        :return: The variable of this DeviceSchema.  # noqa: E501
        :rtype: list[DeviceSchemaVariable]
        """
        return self._variable

    @variable.setter
    def variable(self, variable):
        """Sets the variable of this DeviceSchema.

        Playbook variable configuration  # noqa: E501

        :param variable: The variable of this DeviceSchema.  # noqa: E501
        :type: list[DeviceSchemaVariable]
        """

        self._variable = variable

    @property
    def vendor(self):
        """Gets the vendor of this DeviceSchema.  # noqa: E501


        :return: The vendor of this DeviceSchema.  # noqa: E501
        :rtype: DeviceSchemaVendor
        """
        return self._vendor

    @vendor.setter
    def vendor(self, vendor):
        """Sets the vendor of this DeviceSchema.


        :param vendor: The vendor of this DeviceSchema.  # noqa: E501
        :type: DeviceSchemaVendor
        """

        self._vendor = vendor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DeviceSchema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceSchema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class WorkflowCommandSchema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'command_tag': 'str',
        'commands': 'list[WorkflowCommandSchemaCommands]',
        'ignore': 'list[object]',
        'delay': 'str',
        'repeat': 'float',
        'type': 'str',
        'arguments': 'list[str]',
        'environment': 'list[str]',
        'device': 'list[str]',
        'device_group': 'list[str]'
    }

    attribute_map = {
        'command_tag': 'command-tag',
        'commands': 'commands',
        'ignore': 'ignore',
        'delay': 'delay',
        'repeat': 'repeat',
        'type': 'type',
        'arguments': 'arguments',
        'environment': 'environment',
        'device': 'device',
        'device_group': 'device-group'
    }

    def __init__(self, command_tag=None, commands=None, ignore=None, delay='10s', repeat=None, type=None, arguments=None, environment=None, device=None, device_group=None):  # noqa: E501
        """WorkflowCommandSchema - a model defined in Swagger"""  # noqa: E501

        self._command_tag = None
        self._commands = None
        self._ignore = None
        self._delay = None
        self._repeat = None
        self._type = None
        self._arguments = None
        self._environment = None
        self._device = None
        self._device_group = None
        self.discriminator = None

        self.command_tag = command_tag
        if commands is not None:
            self.commands = commands
        if ignore is not None:
            self.ignore = ignore
        if delay is not None:
            self.delay = delay
        if repeat is not None:
            self.repeat = repeat
        if type is not None:
            self.type = type
        if arguments is not None:
            self.arguments = arguments
        if environment is not None:
            self.environment = environment
        if device is not None:
            self.device = device
        if device_group is not None:
            self.device_group = device_group

    @property
    def command_tag(self):
        """Gets the command_tag of this WorkflowCommandSchema.  # noqa: E501

        Command tag  # noqa: E501

        :return: The command_tag of this WorkflowCommandSchema.  # noqa: E501
        :rtype: str
        """
        return self._command_tag

    @command_tag.setter
    def command_tag(self, command_tag):
        """Sets the command_tag of this WorkflowCommandSchema.

        Command tag  # noqa: E501

        :param command_tag: The command_tag of this WorkflowCommandSchema.  # noqa: E501
        :type: str
        """
        if command_tag is None:
            raise ValueError("Invalid value for `command_tag`, must not be `None`")  # noqa: E501

        self._command_tag = command_tag

    @property
    def commands(self):
        """Gets the commands of this WorkflowCommandSchema.  # noqa: E501

        List of commands to execute  # noqa: E501

        :return: The commands of this WorkflowCommandSchema.  # noqa: E501
        :rtype: list[WorkflowCommandSchemaCommands]
        """
        return self._commands

    @commands.setter
    def commands(self, commands):
        """Sets the commands of this WorkflowCommandSchema.

        List of commands to execute  # noqa: E501

        :param commands: The commands of this WorkflowCommandSchema.  # noqa: E501
        :type: list[WorkflowCommandSchemaCommands]
        """

        self._commands = commands

    @property
    def ignore(self):
        """Gets the ignore of this WorkflowCommandSchema.  # noqa: E501

        Ignore if this command fails  # noqa: E501

        :return: The ignore of this WorkflowCommandSchema.  # noqa: E501
        :rtype: list[object]
        """
        return self._ignore

    @ignore.setter
    def ignore(self, ignore):
        """Sets the ignore of this WorkflowCommandSchema.

        Ignore if this command fails  # noqa: E501

        :param ignore: The ignore of this WorkflowCommandSchema.  # noqa: E501
        :type: list[object]
        """

        self._ignore = ignore

    @property
    def delay(self):
        """Gets the delay of this WorkflowCommandSchema.  # noqa: E501

        Delay between this command's repeated attempts  # noqa: E501

        :return: The delay of this WorkflowCommandSchema.  # noqa: E501
        :rtype: str
        """
        return self._delay

    @delay.setter
    def delay(self, delay):
        """Sets the delay of this WorkflowCommandSchema.

        Delay between this command's repeated attempts  # noqa: E501

        :param delay: The delay of this WorkflowCommandSchema.  # noqa: E501
        :type: str
        """

        self._delay = delay

    @property
    def repeat(self):
        """Gets the repeat of this WorkflowCommandSchema.  # noqa: E501

        Repeat this command on failure  # noqa: E501

        :return: The repeat of this WorkflowCommandSchema.  # noqa: E501
        :rtype: float
        """
        return self._repeat

    @repeat.setter
    def repeat(self, repeat):
        """Sets the repeat of this WorkflowCommandSchema.

        Repeat this command on failure  # noqa: E501

        :param repeat: The repeat of this WorkflowCommandSchema.  # noqa: E501
        :type: float
        """

        self._repeat = repeat

    @property
    def type(self):
        """Gets the type of this WorkflowCommandSchema.  # noqa: E501

        Type of the data produced or consumed  # noqa: E501

        :return: The type of this WorkflowCommandSchema.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this WorkflowCommandSchema.

        Type of the data produced or consumed  # noqa: E501

        :param type: The type of this WorkflowCommandSchema.  # noqa: E501
        :type: str
        """
        allowed_values = ["data-xml", "json", "text"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def arguments(self):
        """Gets the arguments of this WorkflowCommandSchema.  # noqa: E501


        :return: The arguments of this WorkflowCommandSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this WorkflowCommandSchema.


        :param arguments: The arguments of this WorkflowCommandSchema.  # noqa: E501
        :type: list[str]
        """

        self._arguments = arguments

    @property
    def environment(self):
        """Gets the environment of this WorkflowCommandSchema.  # noqa: E501


        :return: The environment of this WorkflowCommandSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this WorkflowCommandSchema.


        :param environment: The environment of this WorkflowCommandSchema.  # noqa: E501
        :type: list[str]
        """

        self._environment = environment

    @property
    def device(self):
        """Gets the device of this WorkflowCommandSchema.  # noqa: E501


        :return: The device of this WorkflowCommandSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._device

    @device.setter
    def device(self, device):
        """Sets the device of this WorkflowCommandSchema.


        :param device: The device of this WorkflowCommandSchema.  # noqa: E501
        :type: list[str]
        """

        self._device = device

    @property
    def device_group(self):
        """Gets the device_group of this WorkflowCommandSchema.  # noqa: E501


        :return: The device_group of this WorkflowCommandSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._device_group

    @device_group.setter
    def device_group(self, device_group):
        """Sets the device_group of this WorkflowCommandSchema.


        :param device_group: The device_group of this WorkflowCommandSchema.  # noqa: E501
        :type: list[str]
        """

        self._device_group = device_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkflowCommandSchema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowCommandSchema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from first import first

from jnpr.healthbot.exception import SchemaError, NotFoundError
from jnpr.healthbot.swagger.models.device_schema import DeviceSchema
from jnpr.healthbot.swagger.models.device_group_schema import DeviceGroupSchema
from jnpr.healthbot.swagger.models.network_group_schema import NetworkGroupSchema

from jnpr.healthbot.swagger.models.device_health_tree import DeviceHealthTree
from jnpr.healthbot.swagger.models.device_group_health_tree import DeviceGroupHealthTree
from jnpr.healthbot.swagger.models.network_health_tree import NetworkHealthTree

from jnpr.healthbot.modules import BaseModule

import logging
logger = logging.getLogger(__file__)


class Device(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """

        super().__init__(hbot)

    def add(self, device_id: str = None, host: str = None,
            username: str = None, password: str = None,
            schema: DeviceSchema = None, **kwargs):
        """
        Add device to HealthBot

        :param str device_id: The name of the device as provided by the User
        :param str host: The hostname/ip-address of the target device
        :param str username: The login user-name for the target device
        :param str password: The login password for the user
        :param object schema: `DeviceSchema <jnpr.healthbot.swagger.models.html#deviceschema>`_

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            from jnpr.healthbot import DeviceSchema

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                ds = DeviceSchema(device_id='xyz', host='xx.xxx.xxx.xxx',
                      authentication={"password": {"password": "xxxxx", "username": "xxxxx"}})

                # we can also later assign values like this
                ds.description = "HbEZ testing"

                # This will add device in candidate DB
                hb.device.add(schema=ds)

                # commit changes to master DB
                hb.commit()

        """
        def _add_device(device_id=None):
            if kwargs:
                if schema is not None:
                    raise SystemError("schema and kwargs are mutually exclusive")
                device_schema = DeviceSchema(device_id=device_id, host=host, **kwargs)
                if username is not None and password is not None:
                    device_schema.authentication = {
                            "password": {
                                "password": password,
                                "username": username
                            }
                        }
                payload = self.hbot._create_payload(device_schema)
            elif schema is not None:
                payload = self.hbot._create_payload(schema)
                device_id = schema.device_id
            else:
                payload = {
                    "authentication": {
                        "password": {
                            "password": password,
                            "username": username
                        }
                    },
                    "device-id": device_id,
                    "host": host,
                }
            url = self.hbot.urlfor.device(device_id)
            response = self.api.post(url, json=payload)
            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()
            return True

        if schema is not None:
            if not isinstance(schema, DeviceSchema):
                raise SchemaError(DeviceSchema)
            device_id = schema.device_id
            host = schema.host

        devices_list_url = self.hbot.urlfor.devices() + self.hbot.apiopt_candidate
        resp = self.api.get(devices_list_url)

        # The API will return a 404 if there are no devices in the system.  We need to check for
        # this condition

        if resp.status_code == 404:
            return _add_device(device_id)

        # examine the existing devices and see if there is one that already
        # exists by this name and host values

        existing_devices = resp.json()['device']

        found = first(
            filter(
                lambda i: i['device-id'] == device_id and i['host'] == host,
                existing_devices))
        if found:
            logger.debug(
                "Device with given device-id '{}' already exists. Updating same.".format(device_id))

        # if we are here, then we need to add this new device

        return _add_device(device_id)

    def delete(self, device_id: str, force: bool = False):
        """
        Remove device from HealthBot

        :param str device_id: The name of the device as provided by the User
        :param bool force: If True, Delete given device from all the device
            group (if present)

        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                # This will delete device in candidate DB
                hb.device.delete('xyz')

                # commit changes to master DB
                hb.commit()

        :returns: True when OK

        """
        device_url = self.hbot.urlfor.device(device_id)
        if force:
            groups_list_url = self.hbot.urlfor.device_groups()
            # Remove Device from the Device Group (requirement before removing
            # Device)
            device_groups_response = self.api.get(groups_list_url)
            # device_groups is the list of dictionaries, each containing the information of
            # device groups present in HBot
            device_groups = device_groups_response.json()
            for each_device_group in device_groups["device-group"]:
                device_list = each_device_group['devices']
                device_group_name = each_device_group['device-group-name']
                # checking if the given device_id present in this device group
                if device_id in device_list:
                    # Delete the device from the device group
                    device_list.remove(device_id)
                    dev_grp_schema = self.hbot.device_group.get(
                        device_group_name)
                    dev_grp_schema.devices = device_list
                    self.hbot.device_group.update(dev_grp_schema)

        # Remove Device from HealthBot
        response = self.api.delete(device_url)
        if response.status_code != 204:
            logger.error(response.text)
        response.raise_for_status()

        return True

    def get_ids(self):
        """
        Return Device IDs for all the devices in HealthBot system

        :return: list of device IDs

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                print(hb.device.get_ids())
        """
        devices_list_url = self.hbot.urlfor.device()
        resp = self.api.get(devices_list_url)

        if resp.status_code == 404:
            return []

        return resp.json()

    def get(self, device_id: str = None, uncommitted: bool = True):
        """
        Get `DeviceSchema <jnpr.healthbot.swagger.models.html#deviceschema>`_ for
        given device id or list for all devices

        :param str device_id: The name of the device as provided by the User
        :param bool uncommitted: True includes fetches uncommitted changes,
        False restricts data set to only committed changes


        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                device = hb.device.get('vmx')
                print(device)

                devices = hb.device.get()
                for device in devices:
                    print(device)

        :return: `DeviceSchema(s) <jnpr.healthbot.swagger.models.html#deviceschema>`_
        """
        if device_id is not None:
            device_url = self.hbot.urlfor.device(device_id)
            if uncommitted:
                device_url += self.hbot.apiopt_candidate
            response = self.api.get(device_url)
            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()
            return self.hbot._create_schema(response, DeviceSchema)
        else:
            device_list = []

            devices_list_url = self.hbot.urlfor.devices()
            if uncommitted:
                devices_list_url += self.hbot.apiopt_candidate
            resp = self.api.get(devices_list_url)

            if resp.status_code == 404:
                return []

            # examine the existing devices and return a list of devices

            existing_devices = resp.json()['device']
            for device in existing_devices:
                device = self.hbot._create_schema(device, DeviceSchema)
                device_list.append(device)

            return device_list

    def update(self, schema: DeviceSchema = None, **kwargs):
        """
        Update `DeviceSchema <jnpr.healthbot.swagger.models.html#deviceschema>`_ for
        given device schema

        Passing Schema invoke `put` and kwargs `post`

        :param obj schema: `DeviceSchema <jnpr.healthbot.swagger.models.html#deviceschema>`_
        :param object kwargs: key values, which can be used to create
            DeviceSchema
            Check `DeviceSchema <jnpr.healthbot.swagger.models.html#deviceschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                schemaObj = hb.device.get('xyz')
                schemaObj.description = 'changed description'
                hb.device.update(schemaObj)

                hb.device.update(device_id="xyz", host='xx.xxx.x.xx', system_id="xxxx")

        :returns: True when OK
        """
        if schema is None:
            schema = DeviceSchema(**kwargs)
            call = self.api.post
        else:
            if not isinstance(schema, DeviceSchema):
                raise SchemaError(DeviceSchema)
            call = self.api.put
        payload = self.hbot._create_payload(schema)
        device_id = schema.device_id
        device_url = self.hbot.urlfor.device(device_id)
        response = call(device_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True

    def get_facts(self, device_id: str = None, uncommitted: bool = True):
        """
        Get device(s) facts. Get facts for provided device id, if device
        id is not provided, get facts for all devices

        :param str device_id: The name of the device as provided by the User
        :param bool uncommitted: True includes fetches uncommitted changes,
        False restricts data set to only committed changes


        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            from pprint import pprint

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                facts = hb.device.get_facts('vmx')
                pprint(facts)
                facts = hb.device.get_facts()
                pprint(facts)

        :return: Single/List of dicts of facts

        """
        if device_id is not None:
            device_url = self.hbot.urlfor.device_facts(device_id)
            if uncommitted:
                device_url += self.hbot.apiopt_candidate
            response = self.api.get(device_url)
            response.raise_for_status()
            return response.json()
        else:
            device_url = self.hbot.urlfor.devices_facts()
            if uncommitted:
                device_url += self.hbot.apiopt_candidate
            response = self.api.get(device_url)
            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()
            return response.json()

    def health(self, device_id: str):
        """
        Returns health of given Device id
        `DeviceHealthTree <jnpr.healthbot.swagger.models.html#deviceheathtree>`_

        :param str device_id: The name of the device as provided by the User

        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                print(hb.device.health('core'))

        :return: `DeviceHealthTree <jnpr.healthbot.swagger.models.html#deviceheathtree>`_
        """

        device_health_url = self.hbot.urlfor.device_health(device_id)
        resp = self.api.get(device_health_url)

        if resp.status_code == 404:
            return {}
        return self.hbot._create_schema(resp, DeviceHealthTree)


class DeviceGroup(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """

        super().__init__(hbot)

    def add(self, schema: DeviceGroupSchema = None, **kwargs):
        """
        Add device group to HealthBot

        :param object schema: `DeviceGroupSchema <jnpr.healthbot.swagger.models.html#devicegroupschema>`_
        :param object kwargs: key values, which can be used to create
            DeviceGroupSchema
            Check `DeviceGroupSchema <jnpr.healthbot.swagger.models.html#devicegroupschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            from jnpr.healthbot import DeviceSchema
            from jnpr.healthbot import DeviceGroupSchema

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                ds = DeviceSchema(device_id='xyz', host='xx.xxx.xxx.xxx',
                      authentication={"password": {"password": "xxxxx", "username": "xxxxx"}})

                # This will add device in candidate DB
                hb.device.add(schema=ds)

                dgs = DeviceGroupSchema(device_group_name="edge",
                                                description="All devices on the edge",
                                                devices=['xyz'])
                hb.device_group.add(dgs)

                # commit changes to master DB
                hb.commit()

        :returns: True when OK

        """
        if schema is None:
            schema = DeviceGroupSchema(**kwargs)
        else:
            if not isinstance(schema, DeviceGroupSchema):
                raise SchemaError(DeviceGroupSchema)
        payload = self.hbot._create_payload(schema)
        device_group_url = self.hbot.urlfor.device_group(
            payload['device-group-name'])
        # Add Device Group to the Healthbot
        response = self.api.post(device_group_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True

    def delete(self, device_group_name: str, force: bool = False):
        """
        Remove device group to HealthBot

        :param str device_group_name: The name of the device group to be deleted
        :param bool force: If True, First delete services for given device group

        Example:
        ::
            hb.devices.delete('edge')
            hb.commit()

        :returns: True when OK
        """

        if force:
            services_device_group_url = self.hbot.urlfor.services_device_group()
            response = self.api.get(services_device_group_url)
            if device_group_name in response.json():
                services_device_group_url = self.hbot.urlfor.services_device_group(
                    device_group_name)
                response = self.api.delete(services_device_group_url)
                if response.status_code != 204:
                    logger.error(response.text)
                response.raise_for_status()
        device_group_url = self.hbot.urlfor.device_group(device_group_name)
        response = self.api.delete(device_group_url)
        if response.status_code != 204:
            logger.error(response.text)
        response.raise_for_status()

        return True

    def get(self, device_group_name: str = None, uncommitted: bool = True):
        """
        Get `DeviceGroupSchema <jnpr.healthbot.swagger.models.html#devicegroupschema>`_ for
        given device group name or list for all device groups

        :param str device_group_name: Name of the device-group
        :param bool uncommitted: True includes fetches uncommitted changes,
                False restricts data set to only committed changes

        Example:
        ::
            device_group_schema = hb.device_group.get('edge')

            groups = hb.device_group.get()
            for group in groups:
                print(group)

        :return: `DeviceGroupSchema(s) <jnpr.healthbot.swagger.models.html#devicegroupschema>`_
        """
        if device_group_name is not None:
            device_group_url = self.hbot.urlfor.device_group(device_group_name)
            if uncommitted:
                device_group_url += self.hbot.apiopt_candidate

            res = self.api.get(device_group_url)

            # if 404 is returned, it means there is not a device group by that name
            # we need to explicitly check for this given the API behavior

            if res.status_code == 404:
                return None

            return self.hbot._create_schema(res, DeviceGroupSchema)
        else:
            device_groups_url = self.hbot.urlfor.device_groups()
            if uncommitted:
                device_groups_url += self.hbot.apiopt_candidate

            response = self.api.get(device_groups_url)

            if response.status_code == 404:
                return []

            response_json = response.json()
            if response.status_code != 200:
                logger.error(response.text)
                raise NotFoundError(response_json)
            device_group_list = []
            existing_device_groups = response_json['device-group']
            for device_group in existing_device_groups:
                obj = self.hbot._create_schema(device_group, DeviceGroupSchema)
                device_group_list.append(obj)
            return device_group_list

    def update(self, schema: DeviceGroupSchema = None, **kwargs):
        """
        Update `DeviceGroupSchema <jnpr.healthbot.swagger.models.html#devicegroupschema>`_ for
        given device schema

        Passing Schema invoke `put` and kwargs `post`

        :param obj schema: `DeviceGroupSchema <jnpr.healthbot.swagger.models.html#devicegroupschema>`_
        :param object kwargs: key values, which can be used to create
            DeviceGroupSchema
            Check `DeviceGroupSchema <jnpr.healthbot.swagger.models.html#devicegroupschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                schemaObj = hb.device_group.get('Core')
                schemaObj.description = "Changed"
                hb.device_group.update(schemaObj)

        :returns: True when OK

        """
        if schema is None:
            schema = DeviceGroupSchema(**kwargs)
            call = self.api.post
        else:
            if not isinstance(schema, DeviceGroupSchema):
                raise SchemaError(DeviceGroupSchema)
            call = self.api.put
        payload = self.hbot._create_payload(schema)
        device_group_url = self.hbot.urlfor.device_group(
            payload['device-group-name'])
        response = call(device_group_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True

    def check_device_in_group(self, device_name: str, device_group_name: str):
        """
        This method check if the device is a member of the given device-group

        :param str device_name: Name of the device
        :param str device_group_name: Name of the device-group

        Example:
        ::
            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                print(hb.device_group.check_device_in_group('vmx', 'QFabric'))

        Returns:
            True if action successful
        """
        # retrieve the current device-group dataset and determine if the given device name is already
        # a member of the group.  If so, return True

        group_data = self.get(device_group_name)
        if group_data is None:
            return False
        device_list = group_data.to_dict().get('devices', [])
        return device_name in device_list

    def add_device_in_group(self, device_name: str, device_group_name: str):
        """
        This method ensures that the given device is a member of the given
        device-group

        :param str device_name: Name of the device
        :param str device_group_name: Name of the device-group

        Example:
        ::
            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                hb.device_group.add_device_in_group('vmx', 'QFabric')

        Raises:
            HTTPError: When error making changes via the HBOT API

        Returns:
            True if action successful
        """
        # retrieve the current device-group dataset and determine if the given device name is already
        # a member of the group.  If so, return True

        if self.check_device_in_group(device_name, device_group_name):
            return True

        # add the device to the list and then store back to the server
        group_data = self.get(device_group_name)
        if group_data is None:
            device_list = []
            group_data = DeviceGroupSchema(device_group_name=device_group_name)
        else:
            device_list = group_data.to_dict().get('devices', [])
        device_list.append(device_name)
        group_data.devices = device_list
        return self.add(group_data)

    def health(self, device_group_name: str):
        """
        Returns health of given Device id
        `DeviceGroupHealthTree <jnpr.healthbot.swagger.models.html#devicegroupheathtree>`_

        :param str device_group_name: The name of the device group

        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                print(hb.device_group.health('edge'))

        :return: `DeviceGroupHealthTree <jnpr.healthbot.swagger.models.html#devicegroupheathtree>`_
        """

        device_group_health_url = self.hbot.urlfor.device_group_health(
            device_group_name)
        resp = self.api.get(device_group_health_url)

        if resp.status_code == 404:
            return {}
        return self.hbot._create_schema(resp, DeviceGroupHealthTree)


class NetworkGroup(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """

        super().__init__(hbot)

    def add(self, schema: NetworkGroupSchema = None, **kwargs):
        """
        Create Network Group

        :param object schema: `NetworkGroupSchema <jnpr.healthbot.swagger.models.html#networkgroupschema>`_
        :param object kwargs: key values, which can be used to create
            NetworkGroupSchema
            Check `NetworkGroupSchema <jnpr.healthbot.swagger.models.html#networkgroupschema>`_
            for details about which all keys can be used

        Example:
        ::
            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                hb.devices.add_network_group(network_group_name="HbEZ")

            # or
            from jnpr.healthbot import HealthBotClient
            from jnpr.healthbot import NetworkGroupSchema

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                ngs = NetworkGroupSchema(network_group_name="HbEZ")
                hb.network_group.add(schema = ngs)

        """
        if schema is None:
            schema = NetworkGroupSchema(**kwargs)
        else:
            if not isinstance(schema, NetworkGroupSchema):
                raise SchemaError(NetworkGroupSchema)
        payload = self.hbot._create_payload(schema)
        # check if the group already exists.  If it does, then return now
        # ... this means this function will not do an "ensure / merge" of data
        # if the group already exists

        network_group_url = self.hbot.urlfor.network_group(
            payload['network-group-name'])
        resp = self.api.get(network_group_url + self.hbot.apiopt_candidate)
        if resp.ok:
            return True
        response = self.api.post(network_group_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()

        return True

    def delete(self, network_group_name: str):
        """
        Delete Network Group

        :param str network_group_name: The name of the network group to be deleted

        Example:
        ::
            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                hb.network_group.delete(network_group_name="HbEZ")
        """

        payload = {'network-group-name': network_group_name}
        network_group_url = self.hbot.urlfor.network_group(network_group_name)
        response = self.api.delete(network_group_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True

    def get(self, network_group_name: str = None, uncommitted: bool = True):
        """
        get Network Group(s) details

        :param str network_group_name: The name of the network group to be fetched
        :param bool uncommitted: True includes fetches uncommitted changes,
                False restricts data set to only committed changes

        Example:
        ::
            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                print(hb.network_group.get(network_group_name="HbEZ"))
                # for all network groups
                print(hb.network_group.get())

        """
        if network_group_name is not None:
            network_group_url = self.hbot.urlfor.network_group(
                network_group_name)
            if uncommitted:
                network_group_url += self.hbot.apiopt_candidate
            response = self.api.get(network_group_url)
            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()
            return self.hbot._create_schema(response, NetworkGroupSchema)
        else:
            network_groups_url = self.hbot.urlfor.network_groups()
            if uncommitted:
                network_groups_url += self.hbot.apiopt_candidate
            response = self.api.get(network_groups_url)
            if response.status_code == 404:
                return []
            response_json = response.json()
            if response.status_code != 200:
                logger.error(response.text)
                raise NotFoundError(response_json)
            response.raise_for_status()
            network_group_list = []
            existing_network_groups = response_json['network-group']
            for network_group in existing_network_groups:
                obj = self.hbot._create_schema(
                    network_group, NetworkGroupSchema)
                network_group_list.append(obj)
            return network_group_list

    def update(self, schema: NetworkGroupSchema = None, **kwargs):
        """
        Update `NetworkGroupSchema <jnpr.healthbot.swagger.models.html#networkgroupschema>`_ for
        given network schema object

        Passing Schema invoke `put` and kwargs `post`

        :param obj schema: `NetworkGroupSchema <jnpr.healthbot.swagger.models.html#networkgroupschema>`_
        :param object kwargs: key values, which can be used to create
            NetworkGroupSchema.

        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                schemaObj = hb.network_group.get("HbEZ")
                schemaObj.description = "HbEZ example"
                hb.network_group.update(schemaObj)

        :returns: True when OK

        """
        if schema is None:
            schema = NetworkGroupSchema(**kwargs)
            call = self.api.post
        else:
            if not isinstance(schema, NetworkGroupSchema):
                raise SchemaError(NetworkGroupSchema)
            call = self.api.put
        payload = self.hbot._create_payload(schema)
        network_group_url = self.hbot.urlfor.network_group(
            payload['network-group-name'])
        response = call(network_group_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        return True

    def health(self, network_group_name: str):
        """
        Returns health of given Device id
        `NetworkHealthTree <jnpr.healthbot.swagger.models.html#networkheathtree>`_

        :param str network_group_name: The name of the network group

        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                print(hb.network_group.health('core'))

        :return: `NetworkHealthTree <jnpr.healthbot.swagger.models.html#networkheathtree>`_
        """

        network_group_health_url = self.hbot.urlfor.network_group_health(
            network_group_name)
        resp = self.api.get(network_group_health_url)

        if resp.status_code == 404:
            return {}
        return self.hbot._create_schema(resp, NetworkHealthTree)



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaField(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'constant': 'RuleSchemaConstant',
        'description': 'str',
        'field_name': 'str',
        'formula': 'RuleSchemaFormula',
        'reference': 'RuleSchemaReference',
        'sensor': 'list[RuleSchemaSensor]',
        'type': 'str'
    }

    attribute_map = {
        'constant': 'constant',
        'description': 'description',
        'field_name': 'field-name',
        'formula': 'formula',
        'reference': 'reference',
        'sensor': 'sensor',
        'type': 'type'
    }

    def __init__(self, constant=None, description=None, field_name=None, formula=None, reference=None, sensor=None, type=None):  # noqa: E501
        """RuleSchemaField - a model defined in Swagger"""  # noqa: E501

        self._constant = None
        self._description = None
        self._field_name = None
        self._formula = None
        self._reference = None
        self._sensor = None
        self._type = None
        self.discriminator = None

        if constant is not None:
            self.constant = constant
        if description is not None:
            self.description = description
        self.field_name = field_name
        if formula is not None:
            self.formula = formula
        if reference is not None:
            self.reference = reference
        if sensor is not None:
            self.sensor = sensor
        if type is not None:
            self.type = type

    @property
    def constant(self):
        """Gets the constant of this RuleSchemaField.  # noqa: E501


        :return: The constant of this RuleSchemaField.  # noqa: E501
        :rtype: RuleSchemaConstant
        """
        return self._constant

    @constant.setter
    def constant(self, constant):
        """Sets the constant of this RuleSchemaField.


        :param constant: The constant of this RuleSchemaField.  # noqa: E501
        :type: RuleSchemaConstant
        """

        self._constant = constant

    @property
    def description(self):
        """Gets the description of this RuleSchemaField.  # noqa: E501

        Description about this field  # noqa: E501

        :return: The description of this RuleSchemaField.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RuleSchemaField.

        Description about this field  # noqa: E501

        :param description: The description of this RuleSchemaField.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def field_name(self):
        """Gets the field_name of this RuleSchemaField.  # noqa: E501

        Name of the field. Should be of pattern [a-z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The field_name of this RuleSchemaField.  # noqa: E501
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """Sets the field_name of this RuleSchemaField.

        Name of the field. Should be of pattern [a-z][a-zA-Z0-9_-]*  # noqa: E501

        :param field_name: The field_name of this RuleSchemaField.  # noqa: E501
        :type: str
        """
        if field_name is None:
            raise ValueError("Invalid value for `field_name`, must not be `None`")  # noqa: E501
        if field_name is not None and len(field_name) > 64:
            raise ValueError("Invalid value for `field_name`, length must be less than or equal to `64`")  # noqa: E501
        if field_name is not None and not re.search(r'^[a-z][a-zA-Z0-9_-]*$', field_name):  # noqa: E501
            raise ValueError(r"Invalid value for `field_name`, must be a follow pattern or equal to `/^[a-z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._field_name = field_name

    @property
    def formula(self):
        """Gets the formula of this RuleSchemaField.  # noqa: E501


        :return: The formula of this RuleSchemaField.  # noqa: E501
        :rtype: RuleSchemaFormula
        """
        return self._formula

    @formula.setter
    def formula(self, formula):
        """Sets the formula of this RuleSchemaField.


        :param formula: The formula of this RuleSchemaField.  # noqa: E501
        :type: RuleSchemaFormula
        """

        self._formula = formula

    @property
    def reference(self):
        """Gets the reference of this RuleSchemaField.  # noqa: E501


        :return: The reference of this RuleSchemaField.  # noqa: E501
        :rtype: RuleSchemaReference
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this RuleSchemaField.


        :param reference: The reference of this RuleSchemaField.  # noqa: E501
        :type: RuleSchemaReference
        """

        self._reference = reference

    @property
    def sensor(self):
        """Gets the sensor of this RuleSchemaField.  # noqa: E501


        :return: The sensor of this RuleSchemaField.  # noqa: E501
        :rtype: list[RuleSchemaSensor]
        """
        return self._sensor

    @sensor.setter
    def sensor(self, sensor):
        """Sets the sensor of this RuleSchemaField.


        :param sensor: The sensor of this RuleSchemaField.  # noqa: E501
        :type: list[RuleSchemaSensor]
        """

        self._sensor = sensor

    @property
    def type(self):
        """Gets the type of this RuleSchemaField.  # noqa: E501


        :return: The type of this RuleSchemaField.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RuleSchemaField.


        :param type: The type of this RuleSchemaField.  # noqa: E501
        :type: str
        """
        allowed_values = ["string", "integer", "unsigned-integer", "float"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaField, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaField):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



class SchemaError(Exception):

    """
    Generated in response to a invalid Schema type
    """

    def __init__(self, schema):
        self._schema = schema

    def __repr__(self):
        return "Schema provided is not of {} type".format(self._schema)

    __str__ = __repr__


class NotFoundError(Exception):

    """
    Generated in response to a invalid Schema type
    """

    def __init__(self, detail):
        self.detail = detail.get('detail')
        self.status = detail.get('status')

    def __repr__(self):
        return "{}, {}".format(self.status, self.detail)

    __str__ = __repr__


class ConnectAuthError(Exception):

    """
    Generated if the user-name, password is invalid
    """
    def __init__(self, hbot, msg=None):
        self.hbot = hbot
        self._orig = msg

    def __repr__(self):
        if self._orig:
            return "{}(host: {}, msg: {})".format(self.__class__.__name__,
                                                     self.hbot.server,
                                                     self._orig)
        else:
            return "{}({})".format(self.__class__.__name__,
                                     self.hbot.server)

    __str__ = __repr__



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TaggingprofileSchemaThenAddfield(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'type': 'str',
        'value': 'str',
        'in_memory': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'type': 'type',
        'value': 'value',
        'in_memory': 'in-memory'
    }

    def __init__(self, name=None, type=None, value=None, in_memory=None):  # noqa: E501
        """TaggingprofileSchemaThenAddfield - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._type = None
        self._value = None
        self._in_memory = None
        self.discriminator = None

        self.name = name
        if type is not None:
            self.type = type
        self.value = value
        if in_memory is not None:
            self.in_memory = in_memory

    @property
    def name(self):
        """Gets the name of this TaggingprofileSchemaThenAddfield.  # noqa: E501

        Tagged field name  # noqa: E501

        :return: The name of this TaggingprofileSchemaThenAddfield.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TaggingprofileSchemaThenAddfield.

        Tagged field name  # noqa: E501

        :param name: The name of this TaggingprofileSchemaThenAddfield.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if name is not None and len(name) > 64:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `64`")  # noqa: E501
        if name is not None and not re.search(r'^[a-z][a-zA-Z0-9_-]*$', name):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^[a-z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._name = name

    @property
    def type(self):
        """Gets the type of this TaggingprofileSchemaThenAddfield.  # noqa: E501


        :return: The type of this TaggingprofileSchemaThenAddfield.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this TaggingprofileSchemaThenAddfield.


        :param type: The type of this TaggingprofileSchemaThenAddfield.  # noqa: E501
        :type: str
        """
        allowed_values = ["string", "integer", "unsigned-integer", "float"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def value(self):
        """Gets the value of this TaggingprofileSchemaThenAddfield.  # noqa: E501

        Tagged value  # noqa: E501

        :return: The value of this TaggingprofileSchemaThenAddfield.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this TaggingprofileSchemaThenAddfield.

        Tagged value  # noqa: E501

        :param value: The value of this TaggingprofileSchemaThenAddfield.  # noqa: E501
        :type: str
        """
        if value is None:
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def in_memory(self):
        """Gets the in_memory of this TaggingprofileSchemaThenAddfield.  # noqa: E501

        Look for value in internal cache  # noqa: E501

        :return: The in_memory of this TaggingprofileSchemaThenAddfield.  # noqa: E501
        :rtype: bool
        """
        return self._in_memory

    @in_memory.setter
    def in_memory(self, in_memory):
        """Sets the in_memory of this TaggingprofileSchemaThenAddfield.

        Look for value in internal cache  # noqa: E501

        :param in_memory: The in_memory of this TaggingprofileSchemaThenAddfield.  # noqa: E501
        :type: bool
        """

        self._in_memory = in_memory

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaggingprofileSchemaThenAddfield, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaggingprofileSchemaThenAddfield):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from jnpr.healthbot.swagger.api_client import ApiClient


class DataStoreApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_data_store(self, key, data, group_name, **kwargs):  # noqa: E501
        """Create dashboard details.  # noqa: E501

        Store data-store details in database for the requested group name and key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_data_store(key, data, group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: Key of data_store object (required)
        :param DatastoreSchema data: Value of data_store object (required)
        :param str group_name: Group name (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_data_store_with_http_info(key, data, group_name, **kwargs)  # noqa: E501
        else:
            (data) = self.create_data_store_with_http_info(key, data, group_name, **kwargs)  # noqa: E501
            return data

    def create_data_store_with_http_info(self, key, data, group_name, **kwargs):  # noqa: E501
        """Create dashboard details.  # noqa: E501

        Store data-store details in database for the requested group name and key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_data_store_with_http_info(key, data, group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: Key of data_store object (required)
        :param DatastoreSchema data: Value of data_store object (required)
        :param str group_name: Group name (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['key', 'data', 'group_name', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_data_store" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'key' is set
        if ('key' not in params or
                params['key'] is None):
            raise ValueError("Missing the required parameter `key` when calling `create_data_store`")  # noqa: E501
        # verify the required parameter 'data' is set
        if ('data' not in params or
                params['data'] is None):
            raise ValueError("Missing the required parameter `data` when calling `create_data_store`")  # noqa: E501
        # verify the required parameter 'group_name' is set
        if ('group_name' not in params or
                params['group_name'] is None):
            raise ValueError("Missing the required parameter `group_name` when calling `create_data_store`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_name' in params:
            path_params['group_name'] = params['group_name']  # noqa: E501

        query_params = []
        if 'key' in params:
            query_params.append(('key', params['key']))  # noqa: E501

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/data-store/{group_name}/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_data_store(self, group_name, **kwargs):  # noqa: E501
        """Delete dashboard details.  # noqa: E501

        Delete data_store details for the given group-name, or as per the keys passed in query.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_data_store(group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_name: Group name (required)
        :param str x_iam_token: authentication header object
        :param list[str] key: ID of dashboard
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_data_store_with_http_info(group_name, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_data_store_with_http_info(group_name, **kwargs)  # noqa: E501
            return data

    def delete_data_store_with_http_info(self, group_name, **kwargs):  # noqa: E501
        """Delete dashboard details.  # noqa: E501

        Delete data_store details for the given group-name, or as per the keys passed in query.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_data_store_with_http_info(group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_name: Group name (required)
        :param str x_iam_token: authentication header object
        :param list[str] key: ID of dashboard
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_name', 'x_iam_token', 'key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_data_store" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_name' is set
        if ('group_name' not in params or
                params['group_name'] is None):
            raise ValueError("Missing the required parameter `group_name` when calling `delete_data_store`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_name' in params:
            path_params['group_name'] = params['group_name']  # noqa: E501

        query_params = []
        if 'key' in params:
            query_params.append(('key', params['key']))  # noqa: E501
            collection_formats['key'] = 'csv'  # noqa: E501

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/data-store/{group_name}/', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_data_store(self, group_name, **kwargs):  # noqa: E501
        """Delete dashboard details.  # noqa: E501

        Retrieve data_store details for the given group-name, or as per the keys passed in query.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_data_store(group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_name: Group name (required)
        :param str x_iam_token: authentication header object
        :param list[str] key: Key of data_store object
        :return: DatastoreSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_data_store_with_http_info(group_name, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_data_store_with_http_info(group_name, **kwargs)  # noqa: E501
            return data

    def retrieve_data_store_with_http_info(self, group_name, **kwargs):  # noqa: E501
        """Delete dashboard details.  # noqa: E501

        Retrieve data_store details for the given group-name, or as per the keys passed in query.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_data_store_with_http_info(group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_name: Group name (required)
        :param str x_iam_token: authentication header object
        :param list[str] key: Key of data_store object
        :return: DatastoreSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_name', 'x_iam_token', 'key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_data_store" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_name' is set
        if ('group_name' not in params or
                params['group_name'] is None):
            raise ValueError("Missing the required parameter `group_name` when calling `retrieve_data_store`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_name' in params:
            path_params['group_name'] = params['group_name']  # noqa: E501

        query_params = []
        if 'key' in params:
            query_params.append(('key', params['key']))  # noqa: E501
            collection_formats['key'] = 'csv'  # noqa: E501

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/data-store/{group_name}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DatastoreSchema',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_data_store(self, key, data, group_name, **kwargs):  # noqa: E501
        """Update data_store details.  # noqa: E501

        Update data-store details in database for the requested group name and key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_data_store(key, data, group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: key of data_store (required)
        :param DatastoreSchema data: value of data_store object (required)
        :param str group_name: Group name (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_data_store_with_http_info(key, data, group_name, **kwargs)  # noqa: E501
        else:
            (data) = self.update_data_store_with_http_info(key, data, group_name, **kwargs)  # noqa: E501
            return data

    def update_data_store_with_http_info(self, key, data, group_name, **kwargs):  # noqa: E501
        """Update data_store details.  # noqa: E501

        Update data-store details in database for the requested group name and key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_data_store_with_http_info(key, data, group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: key of data_store (required)
        :param DatastoreSchema data: value of data_store object (required)
        :param str group_name: Group name (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['key', 'data', 'group_name', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_data_store" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'key' is set
        if ('key' not in params or
                params['key'] is None):
            raise ValueError("Missing the required parameter `key` when calling `update_data_store`")  # noqa: E501
        # verify the required parameter 'data' is set
        if ('data' not in params or
                params['data'] is None):
            raise ValueError("Missing the required parameter `data` when calling `update_data_store`")  # noqa: E501
        # verify the required parameter 'group_name' is set
        if ('group_name' not in params or
                params['group_name'] is None):
            raise ValueError("Missing the required parameter `group_name` when calling `update_data_store`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_name' in params:
            path_params['group_name'] = params['group_name']  # noqa: E501

        query_params = []
        if 'key' in params:
            query_params.append(('key', params['key']))  # noqa: E501

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/data-store/{group_name}/', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
